window.Gleam.initSearch([{"doc":"gs","title":"gs","content":"# gs - Gleam Streams\n\n[![Package Version](https://img.shields.io/hexpm/v/gs)](https://hex.pm/packages/gs)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gs/)\n\n`gs` is a lightweight Gleam library for working with streams of data. It provides a variety of functions for creating, transforming, and consuming streams, making it easy to perform local transformations on lists.\n\n## Installation\n\nAdd `gs` to your Gleam project:\n\n```sh\ngleam add gs\n```\n\n## Usage\n\nHere are some examples of how to use `gs`:\n\n### Creating Streams\n\n```gleam\nimport gs.{empty, pure, from_list, from_option, from_result}\n\nlet empty_stream = empty()\nlet single_value_stream = pure(42)\nlet list_stream = [1, 2, 3] |&gt; from_list\nlet option_stream = Some(42) |&gt; from_option\nlet result_stream = Ok(42) |&gt; from_result\n```\n\n### Transforming Streams\n\n```gleam\nimport gs.{repeat, repeat_eval, map, flat_map, filter, take, concat}\n\nlet repeated_stream = 42 |&gt; repeat\nlet evaluated_stream = fn() { 42 } |&gt; repeat_eval\nlet mapped_stream = repeated_stream |&gt; map(fn(x) { x + 1 })\nlet flat_mapped_stream = repeated_stream |&gt; flat_map(fn(x) { pure(x + 1) })\nlet filtered_stream = repeated_stream |&gt; filter(fn(x) { x &gt; 0 })\nlet taken_stream = repeated_stream |&gt; take(5)\nlet concatenated_stream = pure(1) |&gt; concat(pure(2))\n```\n\n### Consuming Streams\n\n```gleam\nimport gs.{fold, to_list, println, debug}\n\nlet sum = repeated_stream |&gt; take(5) |&gt; fold(0, fn(acc, x) { acc + x })\nlet list = repeated_stream |&gt; take(5) |&gt; to_list\nlet printed_stream = pure(&quot;Hello, world!&quot;) |&gt; println\nlet debugged_stream = pure(42) |&gt; debug\n```\n\n### Advanced Usage\n\n```gleam\nimport gs.{chunks, tap, zip, zip_with, zip_all, zip_all_with}\n\nlet chunked_stream = repeated_stream |&gt; take(10) |&gt; chunks(3)\nlet tapped_stream = repeated_stream |&gt; tap(fn(x) { io.println(x) })\nlet zipped_stream = pure(1) |&gt; zip(pure(2))\nlet zipped_with_stream = pure(1) |&gt; zip_with(pure(2), fn(x, y) { x + y })\nlet zipped_all_stream = pure(1) |&gt; zip_all(empty())\nlet zipped_all_with_stream = pure(1) |&gt; zip_all_with(empty(), fn(x, y) { #(x, y) })\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gs&gt;.\n\n## License\n\nThis project is licensed under the Apache License, Version 2.0. See the [LICENSE](LICENSE) file for details.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"gs","title":"Stream","content":"pub type Stream(a) {\n  Stream(pull: fn() -&gt; Option(#(a, Stream(a))))\n}\n A stream of values of type `a`.\nStream(pull: fn() -&gt; Option(#(a, Stream(a))))\n\n\nSynonyms:\ngs.Stream\ngs Stream","url":"gs.html#Stream"},{"doc":"gs","title":"chunks","content":"pub fn chunks(stream: Stream(a), size: Int) -&gt; Stream(List(a))\n Creates a stream that emits chunks of a given size.\n \n Example:\n \n repeat(1) |&gt; take(10) |&gt; chunks(3)\n \nSynonyms:\ngs.chunks\ngs chunks","url":"gs.html#chunks"},{"doc":"gs","title":"concat","content":"pub fn concat(first: Stream(a), second: Stream(a)) -&gt; Stream(a)\n Concatenates two streams.\n \n Example:\n \n pure(1) |&gt; concat(pure(2))\n \nSynonyms:\ngs.concat\ngs concat","url":"gs.html#concat"},{"doc":"gs","title":"debug","content":"pub fn debug(stream: Stream(a)) -&gt; Stream(a)\n Logs each element of a stream for debugging.\n \n Example:\n \n pure(42) |&gt; debug\n \nSynonyms:\ngs.debug\ngs debug","url":"gs.html#debug"},{"doc":"gs","title":"drop","content":"pub fn drop(stream: Stream(a), n: Int) -&gt; Stream(a)\n Drops the first `n` elements from a stream.\n \n Example:\n \n repeat(1) |&gt; drop(5)\n \nSynonyms:\ngs.drop\ngs drop","url":"gs.html#drop"},{"doc":"gs","title":"filter","content":"pub fn filter(\n  stream: Stream(a),\n  pred: fn(a) -&gt; Bool,\n) -&gt; Stream(a)\n Filters a stream based on a predicate.\n \n Example:\n \n repeat(1) |&gt; filter(fn(x) { x &gt; 0 })\n \nSynonyms:\ngs.filter\ngs filter","url":"gs.html#filter"},{"doc":"gs","title":"flat_map","content":"pub fn flat_map(\n  stream: Stream(a),\n  f: fn(a) -&gt; Stream(b),\n) -&gt; Stream(b)\n Flat maps a function over a stream.\n \n Example:\n \n repeat(1) |&gt; flat_map(fn(x) { pure(x + 1) })\n \nSynonyms:\ngs.flat_map\ngs flat_map","url":"gs.html#flat_map"},{"doc":"gs","title":"from_counter","content":"pub fn from_counter(start: Int) -&gt; Stream(Int)\n Creates a stream that counts up from a given number.\n \n Example:\n \n let stream = from_counter(1)\n \nSynonyms:\ngs.from_counter\ngs from_counter","url":"gs.html#from_counter"},{"doc":"gs","title":"from_empty","content":"pub fn from_empty() -&gt; Stream(a)\n Creates an empty stream.\n \n Example:\n \n let stream = from_empty()\n \nSynonyms:\ngs.from_empty\ngs from_empty","url":"gs.html#from_empty"},{"doc":"gs","title":"from_list","content":"pub fn from_list(items: List(a)) -&gt; Stream(a)\n Creates a stream from a list of items.\n \n Example:\n \n [1, 2, 3] |&gt; from_list\n \nSynonyms:\ngs.from_list\ngs from_list","url":"gs.html#from_list"},{"doc":"gs","title":"from_option","content":"pub fn from_option(option: Option(a)) -&gt; Stream(a)\n Creates a stream from an option.\n \n Example:\n \n Some(42) |&gt; from_option\n \nSynonyms:\ngs.from_option\ngs from_option","url":"gs.html#from_option"},{"doc":"gs","title":"from_pure","content":"pub fn from_pure(value: a) -&gt; Stream(a)\n Creates a stream with a single value.\n \n Example:\n \n let stream = pure(42)\n \nSynonyms:\ngs.from_pure\ngs from_pure","url":"gs.html#from_pure"},{"doc":"gs","title":"from_range","content":"pub fn from_range(start: Int, end: Int) -&gt; Stream(Int)\n Creates a stream that counts up from a given number, including the end.\n \n Example:\n \n let stream = from_range(1, 5)\n \nSynonyms:\ngs.from_range\ngs from_range","url":"gs.html#from_range"},{"doc":"gs","title":"from_range_exclusive","content":"pub fn from_range_exclusive(start: Int, end: Int) -&gt; Stream(Int)\n Creates a stream that counts up from a given number, excluding the end.\n \n Example:\n \n let stream = from_range_exclusive(1, 5)\n \nSynonyms:\ngs.from_range_exclusive\ngs from_range_exclusive","url":"gs.html#from_range_exclusive"},{"doc":"gs","title":"from_repeat","content":"pub fn from_repeat(value: a) -&gt; Stream(a)\n Repeats a value indefinitely in a stream.\n \n Example:\n \n 42 |&gt; repeat\n \nSynonyms:\ngs.from_repeat\ngs from_repeat","url":"gs.html#from_repeat"},{"doc":"gs","title":"from_repeat_eval","content":"pub fn from_repeat_eval(f: fn() -&gt; a) -&gt; Stream(a)\n Repeats the result of a function indefinitely in a stream.\n \n Example:\n \n fn() { 42 } |&gt; repeat_eval\n \nSynonyms:\ngs.from_repeat_eval\ngs from_repeat_eval","url":"gs.html#from_repeat_eval"},{"doc":"gs","title":"from_result","content":"pub fn from_result(result: Result(a, b)) -&gt; Stream(a)\n Creates a stream from a result.\n \n Example:\n \n Ok(42) |&gt; from_result\n \nSynonyms:\ngs.from_result\ngs from_result","url":"gs.html#from_result"},{"doc":"gs","title":"from_tick","content":"pub fn from_tick(delay_ms: Int) -&gt; Stream(Int)\n Creates a stream from a tick in ms.\n \n Example:\n \n from_tick(1000)\n \n \nSynonyms:\ngs.from_tick\ngs from_tick","url":"gs.html#from_tick"},{"doc":"gs","title":"from_timestamp_eval","content":"pub fn from_timestamp_eval() -&gt; Stream(Int)\n Creates a stream that emits the current timestamp.\n\n Example:\n \n const stream = from_timestamp()\n \nSynonyms:\ngs.from_timestamp_eval\ngs from_timestamp_eval","url":"gs.html#from_timestamp_eval"},{"doc":"gs","title":"intersperse","content":"pub fn intersperse(stream: Stream(a), separator: a) -&gt; Stream(a)\n Interleaves a separator between each element of a stream.\n \n Example:\n \n repeat(1) |&gt; intersperse(0)\n \nSynonyms:\ngs.intersperse\ngs intersperse","url":"gs.html#intersperse"},{"doc":"gs","title":"map","content":"pub fn map(stream: Stream(a), f: fn(a) -&gt; b) -&gt; Stream(b)\n Maps a function over a stream.\n \n Example:\n \n repeat(1) |&gt; map(fn(x) { x + 1 })\n \nSynonyms:\ngs.map\ngs map","url":"gs.html#map"},{"doc":"gs","title":"println","content":"pub fn println(stream: Stream(String)) -&gt; Stream(String)\n Prints each element of a stream to the console.\n \n Example:\n \n pure(&quot;Hello, world!&quot;) |&gt; println\n \nSynonyms:\ngs.println\ngs println","url":"gs.html#println"},{"doc":"gs","title":"recover","content":"pub fn recover(\n  stream: Stream(Result(a, b)),\n  recover: fn(b) -&gt; Stream(a),\n) -&gt; Stream(a)\n Recovers from an error in a stream using the given function.\n Alias for `try_recover`.\nSynonyms:\ngs.recover\ngs recover","url":"gs.html#recover"},{"doc":"gs","title":"sleep","content":"pub fn sleep(stream: Stream(a), delay_ms: Int) -&gt; Stream(a)\n Sleeps for a given number of milliseconds before pulling the next value from a stream.\n \n Example:\n \n repeat(1) |&gt; sleep(1000)\n \nSynonyms:\ngs.sleep\ngs sleep","url":"gs.html#sleep"},{"doc":"gs","title":"take","content":"pub fn take(stream: Stream(a), n: Int) -&gt; Stream(a)\n Takes the first `n` elements from a stream.\n \n Example:\n \n repeat(1) |&gt; take(5)\n \nSynonyms:\ngs.take\ngs take","url":"gs.html#take"},{"doc":"gs","title":"take_while","content":"pub fn take_while(\n  stream: Stream(a),\n  pred: fn(a) -&gt; Bool,\n) -&gt; Stream(a)\n Takes elements from a stream while a predicate is true.\n \n Example:\n \n repeat(1) |&gt; take_while(fn(x) { x &lt; 5 })\n \nSynonyms:\ngs.take_while\ngs take_while","url":"gs.html#take_while"},{"doc":"gs","title":"tap","content":"pub fn tap(stream: Stream(a), f: fn(a) -&gt; b) -&gt; Stream(a)\n Applies a function to each element of a stream for side effects.\n \n Example:\n \n repeat(1) |&gt; tap(fn(x) { io.println(x) })\n \nSynonyms:\ngs.tap\ngs tap","url":"gs.html#tap"},{"doc":"gs","title":"to_fold","content":"pub fn to_fold(\n  stream: Stream(a),\n  initial: b,\n  f: fn(b, a) -&gt; b,\n) -&gt; b\n Folds a stream into a single value.\n \n Example:\n \n repeat(1) |&gt; take(5) |&gt; to_fold(0, fn(acc, x) { acc + x })\n \nSynonyms:\ngs.to_fold\ngs to_fold","url":"gs.html#to_fold"},{"doc":"gs","title":"to_list","content":"pub fn to_list(stream: Stream(a)) -&gt; List(a)\n Collects a stream into a list.\n \n Example:\n \n repeat(1) |&gt; take(5) |&gt; to_list\n \nSynonyms:\ngs.to_list\ngs to_list","url":"gs.html#to_list"},{"doc":"gs","title":"to_nil","content":"pub fn to_nil(stream: Stream(a)) -&gt; Nil\n Collects a stream into a Nothing.\n \n Example:\n \n repeat(1) |&gt; take(5) |&gt; to_nil\n \nSynonyms:\ngs.to_nil\ngs to_nil","url":"gs.html#to_nil"},{"doc":"gs","title":"to_option","content":"pub fn to_option(stream: Stream(a)) -&gt; Option(a)\n Collects the first element of a stream into an option.\n \n Example:\n \n repeat(1) |&gt; take(5) |&gt; to_option\n \nSynonyms:\ngs.to_option\ngs to_option","url":"gs.html#to_option"},{"doc":"gs","title":"try_recover","content":"pub fn try_recover(\n  stream: Stream(Result(a, b)),\n  recover: fn(b) -&gt; Stream(a),\n) -&gt; Stream(a)\n Attempts to recover from an error in a stream using the given function.\n If the stream is successful, it remains unchanged.\n If the stream contains an error, the recovery function is used to attempt to create a new stream.\n\n ## Examples\n\n \n [1, 2, 3]\n |&gt; from_list\n |&gt; try_recover(fn(_) { pure(0) })\n // -&gt; Stream containing [1, 2, 3]\n \n\n \n Error(5) \n |&gt; from_result\n |&gt; try_recover(fn(error) { pure(error + 1) })\n // -&gt; Stream containing [6]\n \nSynonyms:\ngs.try_recover\ngs try_recover","url":"gs.html#try_recover"},{"doc":"gs","title":"zip","content":"pub fn zip(left: Stream(a), right: Stream(b)) -&gt; Stream(#(a, b))\n Zips two streams together.\n \n Example:\n \n pure(1) |&gt; zip(pure(2))\n \nSynonyms:\ngs.zip\ngs zip","url":"gs.html#zip"},{"doc":"gs","title":"zip_all","content":"pub fn zip_all(\n  left: Stream(a),\n  right: Stream(b),\n) -&gt; Stream(Option(#(Option(a), Option(b))))\n Zips two streams together, filling with `None` when one stream ends.\n \n Example:\n \n pure(1) |&gt; zip_all(empty())\n \nSynonyms:\ngs.zip_all\ngs zip_all","url":"gs.html#zip_all"},{"doc":"gs","title":"zip_all_with","content":"pub fn zip_all_with(\n  left: Stream(a),\n  right: Stream(b),\n  f: fn(Option(a), Option(b)) -&gt; c,\n) -&gt; Stream(c)\n Zips two streams together with a function, filling with `None` when one stream ends.\n \n Example:\n \n pure(1) |&gt; zip_all_with(empty(), fn(x, y) { #(x, y) })\n \nSynonyms:\ngs.zip_all_with\ngs zip_all_with","url":"gs.html#zip_all_with"},{"doc":"gs","title":"zip_with","content":"pub fn zip_with(\n  left: Stream(a),\n  right: Stream(b),\n  f: fn(a, b) -&gt; c,\n) -&gt; Stream(c)\n Zips two streams together with a function.\n \n Example:\n \n pure(1) |&gt; zip_with(pure(2), fn(x, y) { x + y })\n \nSynonyms:\ngs.zip_with\ngs zip_with","url":"gs.html#zip_with"},{"doc":"gs","title":"gs","content":"","url":"gs.html"}]);